//
//  BitbucketAPIHelpers.h
//  BitbucketAPI
//
//  Created by Marc Beyerlin on 04.07.13.
//  Copyright (c) 2013 Fournova GmbH. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface BitbucketAPIHelpers : NSObject

/** @name Generating API URIs */

+ (NSURL *)APIHostURL;

+ (NSURL *)makeAPIURLWithResourcePath:(NSString *)resourcePath params:(NSDictionary *)params;
+ (NSURL *)makeAPIURLWithResourcePath:(NSString *)resourcePath params:(NSDictionary *)params usesAPIVersion1:(BOOL)usesAPIVersion1;
+ (NSString *)makeAPIResourcePathWithPathComponents:(NSArray *)pathComponents;
+ (NSDictionary *)makeAPIRequestParamsWithOptions:(NSDictionary *)options defaultOptions:(NSDictionary *)defaultOptions;

/** @name Generating User API Resource Paths */

+ (NSString *)userAPIResourcePath;
+ (NSString *)userAPIResourcePathWithUsername:(NSString *)username;

/** @name Generating Repository API Resource Paths */

+ (NSString *)repositoriesAPIResourcePath;
+ (NSString *)repositoriesAPIResourcePathWithUsername:(NSString *)username;
+ (NSString *)repositoryAPIResourcePathWithUsername:(NSString *)username repositoryName:(NSString *)repositoryName;

/** @name Generating Team API Resource Paths */

+ (NSString *)teamsAPIResourcePath;
+ (NSString *)teamAPIResourcePathWithName:(NSString *)teamName;

/** @name Generating Web URLs */

+ (NSURL *)userWebURLForUser:(NSString *)userName;
+ (NSURL *)repositoryWebURLForUser:(NSString *)userName repository:(NSString *)repositoryName;

/** @name Querying Remote URLs */

+ (NSString *)userNameFromRemoteURL:(NSURL *)remoteURL;
+ (NSString *)repositoryNameFromRemoteURL:(NSURL *)remoteURL;

/** @name Generating Pull Request API Resource Paths */

+ (NSString *)pullRequestAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug;
+ (NSString *)pullRequestAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug pullRequestID:(NSNumber *)pullRequestID;
+ (NSString *)createPullRequestAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug;
+ (NSString *)mergePullRequestAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug pullRequestID:(NSNumber *)pullRequestID;
+ (NSString *)closePullRequestAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug pullRequestID:(NSNumber *)pullRequestID;
+ (NSString *)editPullRequestDescriptionAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug pullRequestID:(NSNumber *)pullRequestID;

/** @name Generating Pull Request Comments API Resource Paths */

+ (NSString *)pullRequestCommentsAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug pullRequestID:(NSNumber *)pullRequestID;
+ (NSString *)createPullRequestCommentsAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug pullRequestID:(NSNumber *)pullRequestID;
+ (NSString *)deletePullRequestCommentsAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug pullRequestID:(NSNumber *)pullRequestID commentID:(NSNumber *)commentID;
+ (NSString *)editPullRequestCommentsAPIResourcePathWithUsername:(NSString *)username repositorySlug:(NSString *)repositorySlug pullRequestID:(NSNumber *)pullRequestID commentID:(NSNumber *)commentID;

@end
